@@ -97,7 +97,7 @@ def format_geometry(geometry):
     # define network geometry
     if isinstance(geometry, (int, float)):
         geometry = (1, int(geometry), 1)
-    elif isinstance(geometry, tuple):
+    elif isinstance(geometry, (tuple, list)):
         # a tuple is given, can be 1 .. N dimensional
         width = int(geometry[0])
         height = int(geometry[1]) if len(geometry) >= 2 else 1
@@ -228,4 +228,8 @@ def generate_fake_neuron(num, V=0.):
                       post_groups=[], pre_groups=[],
                       pre_synapses=[], post_synapses=[])
     neu.state[0] = V
+    neu.update_state = helper.jit_lambda(lambda neu_state, t: 1)
+    global neuron_no
+    neu.name = 'FakeNeurons-{}'.format(neuron_no)
+    neuron_no += 1
     return neu
