@@ -40,11 +40,14 @@ def AMPA_Ch1(pre, post, connection, **kwargs):
     """
     # base
     # ----
-    name = kwargs.pop('name', 'AMPA_Ch1')
-    var2index = {'s': (2, 0)}
     num_pre = pre.num
     num_post = post.num
-    dt = kwargs.pop('dt', profile.get_dt())
+    dt = profile.get_dt()
+
+    # essential
+    # ---------
+    name = kwargs.pop('name', 'AMPA_Ch1')
+    var2index = {'s': (2, 0)}
     delay = kwargs.pop('delay', None)
     delay_len = format_delay(delay, dt)
 
@@ -72,9 +75,9 @@ def AMPA_Ch1(pre, post, connection, **kwargs):
     def update_state(syn_state, var_index, t):
         # get synaptic state
         s = syn_state[2][0]
-        s = int_f(s, t)
         spike = syn_state[0][0]
         # calculate synaptic state
+        s = int_f(s, t)
         spike_idx = np.where(spike > 0.)[0]
         for i in spike_idx:
             start, end = pre_anchors[:, i]
@@ -98,7 +101,7 @@ def AMPA_Ch1(pre, post, connection, **kwargs):
 
 
 def AMPA_Ch2(pre, post, connection, **kwargs):
-    """AMPA conductance-based synapse (type 1).
+    """AMPA conductance-based synapse (type 2).
 
     .. math::
 
@@ -124,11 +127,14 @@ def AMPA_Ch2(pre, post, connection, **kwargs):
     """
     # base
     # ----
-    name = kwargs.pop('name', 'AMPA_Ch2')
-    var2index = {'s': (2, 0), 'pre_spike_time': (2, 1)}
     num_pre = pre.num
     num_post = post.num
-    dt = kwargs.pop('dt', profile.get_dt())
+    dt = profile.get_dt()
+
+    # essential
+    # ---------
+    name = kwargs.pop('name', 'AMPA_Ch2')
+    var2index = {'s': (2, 0), 'pre_spike_time': (2, 1)}
     delay = kwargs.pop('delay', None)
     delay_len = format_delay(delay, dt)
 
@@ -155,22 +161,22 @@ def AMPA_Ch2(pre, post, connection, **kwargs):
         delay_len, num_pre, num_post, num, num_syn_shape_var=2)
     # The first (num_syn, ) variable is ``s``
     # The second (num_syn, ) variable if the last_spike time
-    state[2][1] = -1e4
+    state[2][1] = -np.inf
 
     # functions
     # ---------
     def update_state(syn_state, var_index, t):
-        # calculate synaptic state
+        # get synaptic state
         spike = syn_state[0][0]
-        last_spike = syn_state[2][1]
         s = syn_state[2][0]
+        last_spike = syn_state[2][1]
+        # calculate synaptic state
         spike_idx = np.where(spike > 0.)[0]
         for i in spike_idx:
             start, end = pre_anchors[:, i]
             last_spike[start: end] = t
         TT = ((t - last_spike) < T_duration).astype(np.float64) * T
-        s = int_s(s, t, TT)
-        s = clip(s, 0., 1.)
+        s = clip(int_s(s, t, TT), 0., 1.)
         syn_state[2][0] = s
         syn_state[2][1] = last_spike
         # get post-synaptic values
