@@ -11,7 +11,7 @@ __all__ = [
 
 
 def VoltageJumpSynapse(pre, post, weights, connection, **kwargs):
-    """Normal synapse.
+    """Voltage jump synapses.
 
     .. math::
 
@@ -37,11 +37,14 @@ def VoltageJumpSynapse(pre, post, weights, connection, **kwargs):
     """
     # base
     # ----
-    name = kwargs.pop('name', 'VoltageJumpSynapse')
-    var2index = dict()
     num_pre = pre.num
     num_post = post.num
     dt = kwargs.pop('dt', profile.get_dt())
+
+    # essential
+    # ---------
+    name = kwargs.pop('name', 'VoltageJumpSynapse')
+    var2index = dict()
     delay = kwargs.pop('delay', None)
     delay_len = format_delay(delay, dt)
 
