@@ -1,7 +1,7 @@
 
 
-# connection.py
-from npbrain.utils.connection import *
+# conn.py
+# from npbrain.utils.conn import *
 
 # input_factory.py
 from npbrain.utils.input_factory import *
@@ -9,8 +9,8 @@ from npbrain.utils.input_factory import *
 # helper.py
 from npbrain.utils.helper import *
 
-# visualization.py
-from npbrain.utils.visualization import *
+# vis.py
+# from npbrain.utils.vis import *
 
 
 
