@@ -5,7 +5,7 @@ Connection toolkit.
 import numpy as np
 
 __all__ = [
-    'format_connection', 'format_pre2post',
+    'format_connection', 'from_conn_mat',
 
     'one2one', 'all2all',
     'grid_four', 'grid_eight', 'grid_N',
@@ -34,7 +34,11 @@ def format_connection(connection, num_pre, num_post):
             else:
                 i, j, a = _conn_by_name(conn_name, num_pre, num_post, **conn_pars)
         else:
-            i, j, a = connection.pop('i'), connection.pop('j'), connection.pop('a')
+            i, j = connection.pop('i'), connection.pop('j')
+            if 'a' not in connection:
+                i, j, a = from_ij(i, j, num_pre)
+            else:
+                a = connection.pop('a')
     elif callable(connection):
         i, j, a = connection(num_pre, num_post)
     else:
@@ -68,40 +72,78 @@ def _conn_by_name(name, num_pre, num_post, *args, **kwargs):
     return i, j, a
 
 
-def format_pre2post(conn_mat, num_pre):
-    """Format the connectivity matrix to ``pre2post`` linear connection,
-    which means one can access the post connected neuron indexes by pre
-    neuron index.
+def from_conn_mat(conn_mat):
+    """Get the connections from connectivity matrix.
 
-    This function which create to matrices. The first one is the connected
-    post-synaptic neurons, a 1-D array. The second one is the start and the
-    end indexes at the 1-D array for each pre-synaptic neurons.
+    This function which create three arrays. The first one is the connected
+    pre-synaptic neurons, a 1-D array. The second one is the connected
+    post-synaptic neurons, another 1-D array. The third one is the start
+    and the end indexes at the 1-D array for each pre-synaptic neurons.
 
     Parameters
     ----------
     conn_mat : numpy.ndarray
-        Connectivity matrix.
-    num_pre : int
-        Number of neurons in the pre-synaptic neuron group.
+        Connectivity matrix with `(num_pre x num_post)` shape.
 
     Returns
     -------
-    tuple
-        (Post-synaptic neuron indexes, pre-synaptic neuron indexes).
-
+    conn_tuple : tuple
+        (Pre-synaptic neuron indexes,
+         post-synaptic neuron indexes,
+         start and end positions of post-synaptic
+         neuron for each pre-synaptic neuron).
     """
+    pre_indexes = []
     post_indexes = []
     pre_anchors = []
     ii = 0
+    num_pre = conn_mat.shape[0]
     for pre_idx in range(num_pre):
-        post_idx = np.where(conn_mat[pre_idx] > 0.)[0]
-        post_indexes.extend(post_idx)
-        len_idx = len(post_idx)
+        post_idxs = np.where(conn_mat[pre_idx] > 0)[0]
+        post_indexes.extend(post_idxs)
+        len_idx = len(post_idxs)
         pre_anchors.append([ii, ii + len_idx])
+        pre_indexes.extend([pre_idx] * len(post_idxs))
         ii += len_idx
     post_indexes = np.array(post_indexes)
     pre_anchors = np.array(pre_anchors).T
-    return post_indexes, pre_anchors
+    return pre_indexes, post_indexes, pre_anchors
+
+
+def from_ij(i, j, num_pre=None):
+    """Format complete connections from `i` and `j` indexes.
+
+    Parameters
+    ----------
+    i : list, numpy.ndarray
+        The pre-synaptic neuron indexes.
+    j : list, numpy.ndarray
+        The post-synaptic neuron indexes.
+    num_pre : int, None
+        The number of the pre-synaptic neurons.
+
+    Returns
+    -------
+    conn_tuple : tuple
+        (pre_indexes, post_indexes, pre_anchors).
+    """
+    conn_i = np.array(i)
+    conn_j = np.array(j)
+    num_pre = np.max(i) + 1 if num_pre is None else num_pre
+    pre_indexes, post_indexes, pre_anchors = [], [], []
+    ii = 0
+    for i in range(num_pre):
+        indexes = np.where(conn_i == i)[0]
+        post_idx = conn_j[indexes]
+        post_len = len(post_idx)
+        pre_indexes.extend([i] * post_len)
+        post_indexes.extend(post_idx)
+        pre_anchors.append([ii, ii + post_len])
+        ii += post_len
+    pre_indexes = np.asarray(pre_indexes)
+    post_indexes = np.asarray(post_indexes)
+    pre_anchors = np.asarray(pre_anchors).T
+    return pre_indexes, post_indexes, pre_anchors
 
 
 # -----------------------------------
